@@ -1,3 +1,7 @@
+# fixes problems with change in all.equal() behavior in R 4.1.x
+expect_eql <- function(...) expect_equal(..., check.environment = FALSE)
+expect_equiv <- function(...) expect_equivalent(..., check.environment = FALSE)
+
 context("Class 'vine_dist'")
 
 set.seed(0)
@@ -48,24 +52,24 @@ test_that("print/summary/dim generics work", {
   s <- summary(vc)
   expect_is(s$margins, "data.frame")
   expect_is(s$copula, "data.frame")
-  expect_equal(nrow(s$margins), 3)
-  expect_equal(ncol(s$margins), 2)
-  expect_equal(nrow(s$copula), 3)
-  expect_equal(ncol(s$copula), 10)
+  expect_eql(nrow(s$margins), 3)
+  expect_eql(ncol(s$margins), 2)
+  expect_eql(nrow(s$copula), 3)
+  expect_eql(ncol(s$copula), 10)
 
-  expect_equivalent(dim(vc)[1], 3)
-  expect_equivalent(dim(vc)[2], 2)
+  expect_equiv(dim(vc)[1], 3)
+  expect_equiv(dim(vc)[2], 2)
 })
 
 test_that("getters work", {
 
   # test get_matrix
-  expect_equivalent(as_rvine_matrix(mat), get_matrix(vc))
+  expect_equiv(as_rvine_matrix(mat), get_matrix(vc))
   expect_error(get_matrix(12))
 
   # test get_pair_copulas
   expect_silent(pcc <- get_pair_copula(vc, 1, 1))
-  expect_equal(bicop, bicop_dist(pcc$family, pcc$rotation, pcc$parameters))
+  expect_eql(bicop, bicop_dist(pcc$family, pcc$rotation, pcc$parameters))
   expect_error(get_pair_copula(12, 1, 1))
   expect_error(get_pair_copula(vc, 1:2, 1))
   expect_error(get_pair_copula(vc, 1, 1:2))
@@ -75,26 +79,26 @@ test_that("getters work", {
   expect_error(get_pair_copula(vc, 1, 12))
 
   # test get_all_pair_copulas
-  expect_equivalent(pcs, get_all_pair_copulas(vc))
-  expect_equivalent(pcs[1:2], get_all_pair_copulas(vc, 1:2))
+  expect_equiv(pcs, get_all_pair_copulas(vc))
+  expect_equiv(pcs[1:2], get_all_pair_copulas(vc, 1:2))
   expect_error(get_all_pair_copulas(12))
   expect_error(get_all_pair_copulas(vc, 0))
   expect_error(get_all_pair_copulas(vc, 12))
 
   # test other getters
-  expect_equivalent(get_parameters(vc, 1, 1), coef(pcs[[1]][[1]]))
-  expect_equivalent(
+  expect_equiv(get_parameters(vc, 1, 1), coef(pcs[[1]][[1]]))
+  expect_equiv(
     get_all_parameters(vc),
     lapply(pcs, function(tree) lapply(tree, coef))
   )
-  expect_equivalent(get_ktau(vc, 1, 1), par_to_ktau(bicop))
-  expect_equivalent(
+  expect_equiv(get_ktau(vc, 1, 1), par_to_ktau(bicop))
+  expect_equiv(
     get_all_ktaus(vc),
     lapply(pcs, function(tree)
       lapply(tree, function(pc) par_to_ktau(pc)))
   )
-  expect_equivalent(get_family(vc, 1, 1), "bb1")
-  expect_equivalent(
+  expect_equiv(get_family(vc, 1, 1), "bb1")
+  expect_equiv(
     get_all_families(vc),
     lapply(pcs, function(tree)
       lapply(tree, function(pc) pc$family))
